@@ -409,7 +409,7 @@ def calc_HZee_j(J, L, S, jx, jy, jz, B):
 
 
 def calc_oef(n, J, L, S):
-    """ 
+    """
     Calculate operator equivalent factors for Stevens Crystal Field
     Hamiltonian in |J, mJ> basis
 
@@ -454,7 +454,7 @@ def calc_oef(n, J, L, S):
     # Each parameter Bkq has its own parameter
     oef = np.zeros(27)
     shift = 0
-    for k in range(2, int(2*J), 2):
+    for k in range(2, np.min([6, int(2*J)])+2, 2):
         oef[shift:shift + 2*k+1] = float(_oef_lambda(k, J, L, S))
         oef[shift:shift + 2*k+1] *= float(_oef_k(k, k, n) / _oef_RedJ(J, k))
         shift += 2*k + 1
